@@ -10,7 +10,7 @@ import click
 from roborock import RoborockException
 from roborock.api import RoborockApiClient
 from roborock.cloud_api import RoborockMqttClient
-from roborock.containers import LoginData, RoborockDeviceInfo
+from roborock.containers import DeviceData, LoginData
 from roborock.util import run_sync
 
 _LOGGER = logging.getLogger(__name__)
@@ -123,10 +123,15 @@ async def command(ctx, cmd, device_id, params):
     home_data = login_data.home_data
     devices = home_data.devices + home_data.received_devices
     device = next((device for device in devices if device.duid == device_id), None)
-    model_specification = next(
-        (product.model_specification for product in home_data.products if product.did == device.duid), None
+    if device is None:
+        raise RoborockException("No device found")
+    model = next(
+        (product.model for product in home_data.products if device is not None and product.did == device.duid),
+        None,
     )
-    device_info = RoborockDeviceInfo(device=device, model_specification=model_specification)
+    if model is None:
+        raise RoborockException(f"Could not find model for device {device.name}")
+    device_info = DeviceData(device=device, model=model)
     mqtt_client = RoborockMqttClient(login_data.user_data, device_info)
     await mqtt_client.send_command(cmd, params)
     mqtt_client.__del__()
