@@ -32,6 +32,7 @@ from .const import (
     FILTER_REPLACE_TIME,
     MAIN_BRUSH_REPLACE_TIME,
     ROBOROCK_Q7_MAX,
+    ROBOROCK_S4_MAX,
     ROBOROCK_S5_MAX,
     ROBOROCK_S6_MAXV,
     ROBOROCK_S6_PURE,
@@ -250,6 +251,13 @@ class Status(RoborockBase):
     unsave_map_flag: Optional[int] = None
 
 
+@dataclass
+class S4MaxStatus(Status):
+    fan_power: Optional[RoborockFanSpeedS6Pure] = None
+    water_box_mode: Optional[RoborockMopIntensityS7] = None
+    mop_mode: Optional[RoborockMopModeS7] = None
+
+
 @dataclass
 class S5MaxStatus(Status):
     fan_power: Optional[RoborockFanSpeedS6Pure] = None
@@ -295,6 +303,7 @@ class S8ProUltraStatus(Status):
 
 
 ModelStatus: dict[str, Type[Status]] = {
+    ROBOROCK_S4_MAX: S4MaxStatus,
     ROBOROCK_S5_MAX: S5MaxStatus,
     ROBOROCK_Q7_MAX: Q7MaxStatus,
     ROBOROCK_S6_MAXV: S6MaxVStatus,
@@ -306,7 +315,7 @@ ModelStatus: dict[str, Type[Status]] = {
 
 
 @dataclass
-class DNDTimer(RoborockBase):
+class DnDTimer(RoborockBase):
     start_hour: Optional[int] = None
     start_minute: Optional[int] = None
     end_hour: Optional[int] = None
@@ -419,12 +428,19 @@ class NetworkInfo(RoborockBase):
 
 
 @dataclass
-class RoborockDeviceInfo(RoborockBase):
+class DeviceData(RoborockBase):
     device: HomeDataDevice
     model: str
+    host: Optional[str] = None
 
 
 @dataclass
 class RoomMapping(RoborockBase):
     segment_id: int
     iot_id: str
+
+
+@dataclass
+class BroadcastMessage(RoborockBase):
+    duid: str
+    ip: str
